@@ -14,6 +14,7 @@ class ModSuiteSanity(unittest.TestCase):
             os.remove("kemExample.tmp")
 
     def sanity_rmcl_model(self):
+        """ Checking sanity of RmcL calculation (example) """
         # Import some unrelated modules
         from numpy import arange, pi
         import matplotlib.pylab as plt
@@ -37,6 +38,7 @@ class ModSuiteSanity(unittest.TestCase):
 #     plt.show()
 
     def sanity_rmcl_fit(self):
+        """ Checking sanity of RmcL fit (example) """
         # Import some unrelated modules
         from numpy import arange, pi, random
         import matplotlib.pylab as plt
@@ -76,6 +78,84 @@ class ModSuiteSanity(unittest.TestCase):
         plt.legend(["Observation", "Model"])
 #     plt.show()
 
+    def sanity_rmclell_calc(self):
+        """
+        Checking sanity of RmcLell (example)
+        """
+        # Import some unrelated modules
+        from numpy import arange, pi
+        import matplotlib.pylab as plt
+        # ... and the model suite
+        from PyAstronomy import modelSuite as ms
+        
+        # Create Rossiter-McLaughlin object (circular orbit)
+        rmcl = ms.RmcL()
+        # and one for an elliptical orbit
+        rmel = ms.RmcLell()
+        
+        # Assign parameter values
+        rmcl.assignValue({"a":6.7, "lambda":7.2/180.0*pi, "epsilon":0.5, \
+                            "P":1.74, "T0":0.2, "i":87.8/180.*pi, \
+                            "Is":90.0/180.0*pi, "Omega":1.609e-5, "gamma":0.2})
+        rmel.assignValue({"a":6.7, "lambda":7.2/180.0*pi, "epsilon":0.5, \
+                            "P":1.74, "tau":0.2, "i":87.8/180.*pi, "w":-90/180.*pi, \
+                            "e":0.05, "Is":90.0/180.0*pi, "Omega":1.609e-5, "gamma":0.2})
+        
+        
+        # Choose some time axis and calculate model
+        time = arange(100)/100.0 * 0.2 + 0.1
+        rvc = rmcl.evaluate(time)
+        rve = rmel.evaluate(time)
+        
+        # Let's see what happened...
+#         plt.ylabel("Radial velocity [stellar-radii/s]")
+#         plt.xlabel("Time [d]")
+#         plt.plot(time, rvc, 'b.-', label="circular")
+#         plt.plot(time, rve, 'r.-', label="elliptical")
+#         plt.legend()
+#         plt.show()
+
+    def sanity_rmcl_vs_rmclell(self):
+        """ Cross-checking Rmcl and RmcLell """
+        from numpy import arange, pi
+        import numpy as np
+        # ... and the model suite
+        from PyAstronomy import modelSuite as ms
+        
+        # Create Rossiter-McLaughlin object
+        rmcl = ms.RmcL()
+        r2 = ms.RmcLell()
+        
+        np.random.seed(9234667)
+        
+        for i in range(10):
+        
+            a = np.random.random()*5 + 3
+            l = np.random.random()*180 - 90
+            inc = np.random.random()*2 + 88
+            Omega = 1e-5 + np.random.random()*1e-5
+        
+            # Set parameters
+            rmcl.assignValue({"a":a, "lambda":l/180.0*pi, "epsilon":0.5, \
+                            "P":1.74, "T0":0.2, "i":inc/180.*pi, \
+                            "Is":80.0/180.0*pi, "Omega":Omega, "gamma":0.2})
+        
+            # Set parameters
+            r2.assignValue({"a":a, "lambda":l/180.0*pi, "epsilon":0.5, \
+                            "P":1.74, "tau":0.2, "i":inc/180.*pi, \
+                            "Is":80.0/180.0*pi, "Omega":Omega, "gamma":0.2,
+                            "e":0.0, "w":-90/180*pi})
+        
+            # Choose some time axis and calculate model
+            time = arange(20)/20.0 * 0.2 - 0.1 + rmcl["T0"]
+            rv = rmcl.evaluate(time)
+            rv2 = r2.evaluate(time)
+            
+            d = np.max(np.abs(rv-rv2))
+            m = np.max(np.abs(rv))
+            self.assertAlmostEqual(d/m, 0.0, delta=1e-8, msg="Elliptical and circular orbit solution for RmcL and RmcLell do not match. " + \
+                                   str(r2.parameters()))
+
     def sanity_SinRadVel(self):
         # Import some unrelated modules
         from numpy import arange, random, ones
@@ -312,6 +392,40 @@ class ModSuiteSanity(unittest.TestCase):
         plt.plot(wvl, m, 'b.-')
 #    plt.show()
 
+
+    def sanity_VoigtAstroP_R_Example(self):
+        """
+        Sanity of VoigtAstroP example with instrumental resolution
+        """
+
+        from PyAstronomy import modelSuite as ms
+        import numpy as np
+        import matplotlib.pylab as plt
+        
+        # Obtain an object of type VoigtAstroP ...
+        v = ms.VoigtAstroP()
+        # ... and set some parameters
+        v["b"] = 40.7
+        v["f"] = 0.5
+        v["w0"] = 1214.0
+        # Damping constant [cm]
+        v["gamma"] = 2e-9
+        
+        # Generate wavelength axis ...
+        wvl = np.linspace(1212.,1216.,200)
+        # ... and evaluate model
+        m = v.evaluate(wvl)
+        
+        # Add (Gaussian) instrumental broadening with resolution 5000
+        v["R"] = 5000
+        mr = v.evaluate(wvl)
+        
+        # Plot result
+#         plt.plot(wvl, m, 'b.-', label="R = inf")
+#         plt.plot(wvl, mr, 'r.-', label="R = 5000")
+#         plt.legend()
+#         plt.show()
+
     def sanity_LyATransmission(self):
         """
         Checking sanity of LyATransmission example
@@ -546,3 +660,40 @@ class VoigtAstroPSanity(unittest.TestCase):
                 
                 self.assertAlmostEqual(i/const, f, delta=1e-2, msg="Normalization of AstroVoigtP is broken: f, w0, i: % g, % g, % g" % (f, w0, i))
 
+    def sanity_instrumentalResolution(self):
+        """
+        Checking integrity of instrumental resolution in VoigtAstroP
+        """
+        import numpy as np
+        from PyAstronomy import modelSuite as ms
+        from PyAstronomy import pyasl
+        
+        v = ms.VoigtAstroP()
+        
+        w0 = 10830
+        
+        for R in [2500, 5000, 80000]:
+        
+            v["w0"] = w0
+            v["b"] = 10.
+            v["gamma"] = 1e-8
+            v["f"] = 100.0
+            v["R"] = 0
+        
+            dw = 40.0
+            w = np.linspace(w0-dw, w0+dw, 4000)
+        
+            m = v.evaluate(w)
+        
+            v["R"] = R
+            m2 = v.evaluate(w)
+        
+            
+            fb = pyasl.instrBroadGaussFast(w, m, R, edgeHandling=None, fullout=False, maxsig=None)
+
+            d = 1000
+            
+            self.assertAlmostEqual(np.max(np.abs(fb[d:-d] - m2[d:-d])/m2[d:-d]), 0.0, delta=1e-10,
+                                   msg="VoigtAstroP instrumental broadening broken for R = " + str(R))
+
+            
